@@ -84,18 +84,13 @@ class KNOTIFICATIONS_EXPORT KNotification : public QObject
     Q_PROPERTY(Urgency urgency READ urgency WRITE setUrgency NOTIFY urgencyChanged)
     /**
      * @copydoc setAutoDelete
-     * @since 5.88
+     * @seince 5.88
      */
     Q_PROPERTY(bool autoDelete READ isAutoDelete WRITE setAutoDelete NOTIFY autoDeleteChanged)
     /**
      * @since 5.90
      */
     Q_PROPERTY(QString xdgActivationToken READ xdgActivationToken NOTIFY xdgActivationTokenChanged)
-    /**
-     * @copydoc setHint
-     * @since 5.101
-     */
-    Q_PROPERTY(QVariantMap hints READ hints WRITE setHints NOTIFY hintsChanged)
 
 public:
     /**
@@ -447,7 +442,7 @@ public:
      */
     void setContexts(const ContextList &contexts);
     /**
-     * append a context at the list of contexts, see KNotification::Context
+     * append a context at the list of contexts, see KNotificaiton::Context
      * @param context the context which is added
      */
     void addContext(const Context &context);
@@ -669,11 +664,6 @@ Q_SIGNALS:
      * @since 5.90
      */
     void xdgActivationTokenChanged();
-    /**
-     * Emitted when @p hints changes.
-     * @since 5.101
-     */
-    void hintsChanged();
 
 public Q_SLOTS:
     /**
@@ -704,7 +694,7 @@ public Q_SLOTS:
      * if you want to show your own presentation in your application, you should use this
      * function, so it will not be automatically closed when there is nothing to show.
      *
-     * Don't forget to deref, or the notification may be never closed if there is no timeout.
+     * Don't forgot to deref, or the notification may be never closed if there is no timeout.
      *
      * @see deref
      */
@@ -738,7 +728,7 @@ public Q_SLOTS:
      * @param hint the hint's key
      * @param value the hint's value
      */
-    Q_INVOKABLE void setHint(const QString &hint, const QVariant &value);
+    void setHint(const QString &hint, const QVariant &value);
 
     /**
      * @since 5.57
@@ -746,13 +736,6 @@ public Q_SLOTS:
      */
     QVariantMap hints() const;
 
-    /**
-     * @since 5.101
-     * Set custom hints on the notification.
-     * @sa setHint
-     */
-    void setHints(const QVariantMap &hints);
-
 private:
     friend class KNotificationManager;
     struct Private;
